.. include:: ../README.rst

API documentation
==========================================
.. automodule:: cromwell_tools.cromwell_tools
   :members:
   :inherited-members:


Table of Contents
=================
.. toctree::
   :maxdepth: 2

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`